﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace HR.DataLayer
{
    public class EmployeeData : HR.DataLayer.IEmployeeData
    {
        public HrEntities DbContext { get; set; }

        public EmployeeData()
        {
            DbContext = new HrEntities();
        }

        public int CreateNewEmployee(Employee employee)
        {
            int result;
            try
            {
                var newEmployee = DbContext.Employees.Create();
                newEmployee.Name = employee.Name;
                newEmployee.Telephone = employee.Telephone;
                newEmployee.EmploymentDate = employee.EmploymentDate;
                newEmployee.Address = employee.Address;
                newEmployee.EmployeeTypeId = employee.EmployeeTypeId;
                DbContext.Employees.Add(newEmployee);
                DbContext.SaveChanges();
                result = newEmployee.Id;
            }
            catch (Exception e)
            {
                result = 0;
            }
            return result;
        }

        public int DeleteEmployee(int id)
        {
            int result;
            try
            {
                var employee = DbContext.Employees.Find(id);
                DbContext.Employees.Remove(employee);
                DbContext.SaveChanges();
                result = 1;
            }
            catch (Exception e)
            {
                result = 0;
            }
            return result;
        }

        public IList<Employee> GetAllEmployees()
        {
            return DbContext.Employees.ToList<Employee>() ?? new List<Employee>();
        }

        public Employee GetEmployeeById(int id)
        {
            return DbContext.Employees.Find(id);
        }

        public IList<Employee> GetEmployeesByEmployeeType(int employeeTypeId)
        {
            return (from e in DbContext.Employees
                    where e.EmployeeTypeId.Equals(employeeTypeId)
                    select e).ToList<Employee>() ?? new List<Employee>();
        } 

        public int UpdateEmployee(Employee employee)
        {
            int result;
            try
            {
                var modifiedEmployee = DbContext.Employees.Find(employee.Id);
                modifiedEmployee.Name = employee.Name;
                modifiedEmployee.Telephone = employee.Telephone;
                modifiedEmployee.EmploymentDate = employee.EmploymentDate;
                modifiedEmployee.Address = employee.Address;
                modifiedEmployee.EmployeeTypeId = employee.EmployeeTypeId;
                DbContext.SaveChanges();
                result = modifiedEmployee.Id;
            }
            catch (Exception e)
            {
                result = 0;
            }
            return result;
        }  
    }
}
