﻿using HR.DataLayer;
using HR.Dto;
using ServiceStack.ServiceHost;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using HR.Service.Translators;
using System.Net;
using ServiceStack.Common;
using ServiceStack.Common.Web;

namespace HR.Service
{
    public class EmployeeService : ServiceStack.ServiceInterface.Service, HR.Service.IEmployeeService
    {
        private IEmployeeData _dataLayer;

        public EmployeeService()
        {
            _dataLayer = new EmployeeData();
        }

        /// <summary>
        /// GET /employees/{Id}
        /// </summary>
        public EmployeeResponse Get(HR.Dto.Employee request)
        {
            return new EmployeeResponse { Employee = _dataLayer.GetEmployeeById(request.Id).Translate() };
        }

        /// <summary>
        /// GET /employees 
        /// GET /employees/employeetype/{EmployeeTypeId} 
        /// </summary>
        public EmployeesResponse Get(HR.Dto.Employees request)
        {
            IList<HR.Dto.Employee> employees;
            if (request.EmployeeTypeId.HasValue)
            {
                employees = _dataLayer.GetEmployeesByEmployeeType(request.EmployeeTypeId.Value).Select(x=>x.Translate()).ToList();
            }
            else
            {
                employees = _dataLayer.GetAllEmployees().Select(x => x.Translate()).ToList();        
            }

            return new EmployeesResponse { Employees = employees };
        }

        /// <summary>
        /// POST /employees
        /// </summary>
        public object Post(HR.Dto.Employee request)
        {
            var newEmployeeId = _dataLayer.CreateNewEmployee(request.Translate());

            HttpResult httpResult = ValidateResult(request, newEmployeeId, HttpStatusCode.Created);

            return httpResult;
        }

        /// <summary>
        /// PUT /employees/{Id}
        /// </summary>
        public object Put(HR.Dto.Employee request)
        {
            var result = _dataLayer.UpdateEmployee(request.Translate());

            HttpResult httpResult = ValidateResult(request, result, HttpStatusCode.NoContent);

            return httpResult;
        }

        /// <summary>
        /// DELETE /employees{Id}
        /// </summary>
        public object Delete(HR.Dto.Employee request)
        {
            var result = _dataLayer.DeleteEmployee(request.Id);

            HttpResult httpResult = ValidateResult(request, result, HttpStatusCode.NoContent);

            return httpResult;
        }

        private HttpResult ValidateResult(HR.Dto.Employee request, int result, HttpStatusCode successStatusCode)
        {
            HttpResult httpResult;
            HttpStatusCode statusCode;
            int id;
            if (result > 0)
            {
                id = result;
                statusCode = successStatusCode;
            }
            else
            {
                id = request.Id;
                statusCode = HttpStatusCode.InternalServerError;
            }

            var response = new EmployeeResponse { Employee = request };
            
            return new HttpResult(response)
            {
                StatusCode = statusCode//,
               /* Headers = {
                    {
                        HttpHeaders.Location, base.Request.AbsoluteUri.CombineWith(id)
                    }
                }*/
            };
        }
  
    }
}