﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using HR.Mvc.Models;
using HR.Mvc.Models.HR;
using ServiceStack.Mvc;
using HR.Dto;
using HR.Service;
using HR.Mvc.Translators;

namespace HR.Mvc.Controllers
{
    public class EmployeeController : ServiceStackController
    {
        public IEmployeeService EmployeeService { get; set; }

        //
        // GET: /Employee/

        public ActionResult Index()
        {
            var request = new Employees();

            var employees = EmployeeService.Get(request).Employees.Select(x => x.Translate()).ToList<EmployeeModel>();

            return View(employees);
        }

        //
        // GET: /Employee/Details/5

        public ActionResult Details(int id = 0)
        {
            var request = new Employee { Id = id };

            var employee = EmployeeService.Get(request).Employee.Translate();

            if (employee == null)
            {
                return HttpNotFound();
            }
            return View(employee);
        }

        //
        // GET: /Employee/Create

        public ActionResult Create()
        {
            return View();
        }

        //
        // POST: /Employee/Create

        [HttpPost]
        public ActionResult Create(EmployeeModel employee)
        {
            if (ModelState.IsValid)
            {
                var request = employee.Translate();

                var result = EmployeeService.Post(request);

                //validate result

                return RedirectToAction("Index");
            }

            return View(employee);
        }

        //
        // GET: /Employee/Edit/5

        public ActionResult Edit(int id = 0)
        {
            var request = new Employee { Id = id };

            var employee = EmployeeService.Get(request).Employee.Translate();

            if (employee == null)
            {
                return HttpNotFound();
            }
            return View(employee);
        }

        //
        // POST: /Employee/Edit/5

        [HttpPost]
        public ActionResult Edit(EmployeeModel employee)
        {
            if (ModelState.IsValid)
            {
                var request = employee.Translate();

                var result = EmployeeService.Put(request);

                //validate result

                return RedirectToAction("Index");
            }
            return View(employee);
        }

        //
        // GET: /Employee/Delete/5

        public ActionResult Delete(int id = 0)
        {
            var request = new Employee { Id = id };

            var employee = EmployeeService.Get(request).Employee.Translate();

            if (employee == null)
            {
                return HttpNotFound();
            }
            return View(employee);
        }

        //
        // POST: /Employee/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            var request = new Employee { Id = id };
            var result = EmployeeService.Delete(request);
            //validate result
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            base.Dispose(disposing);
        }
    }
}